@@ -1,13 +1,18 @@
       double precision function dgamma (x)
-c jan 1984 edition.  w. fullerton, c3, los alamos scientific lab.
+c     jan 1984 edition.  w. fullerton, c3, los alamos scientific lab.
 C     double precision x, gamcs(42), dxrel, pi, sinpiy, sq2pil, xmax,
-C    1  xmin, y, d9lgmc, dcsevl, d1mach, dexp, dint, dlog,
-C    2  dsin, dsqrt
-      double precision x, gamcs(42), dxrel, pi, sinpiy, sq2pil, xmax,
-     1  xmin, y, d9lgmc, dcsevl
-      double precision temp
+C     1  xmin, y, d9lgmc, dcsevl, d1mach, dexp, dint, dlog,
+C     2  dsin, dsqrt
+
+      double precision x
+      double precision gamcs(42), dxrel, pi, sinpiy, sq2pil, xmax,
+     1     xmin, xsml, y, temp
+      integer ngam, n, i
+
+      double precision d9lgmc, dcsevl
+      integer initds
 C     external d1mach, d9lgmc, dcsevl, dexp, dint, dlog, dsin, dsqrt,
-C    1  initds
+C     1  initds
       external d9lgmc, dcsevl, initds
 
       double precision   FLTMIN, FLTMAX, EPSMIN, EPSMAX
@@ -18,160 +23,162 @@ C    1  initds
       common /GAMMFD/    IGAMMA, JGAMMA
       save   /GAMMFD/
 c
-c series for gam        on the interval  0.          to  1.00000e+00
-c                                        with weighted error   5.79e-32
-c                                         log weighted error  31.24
-c                               significant figures required  30.00
-c                                    decimal places required  32.05
+c     series for gam        on the interval  0.          to  1.00000e+00
+c     with weighted error   5.79e-32
+c     log weighted error  31.24
+c     significant figures required  30.00
+c     decimal places required  32.05
 c
-      data gam cs(  1) / +.8571195590 9893314219 2006239994 2 d-2      /
-      data gam cs(  2) / +.4415381324 8410067571 9131577165 2 d-2      /
-      data gam cs(  3) / +.5685043681 5993633786 3266458878 9 d-1      /
-      data gam cs(  4) / -.4219835396 4185605010 1250018662 4 d-2      /
-      data gam cs(  5) / +.1326808181 2124602205 8400679635 2 d-2      /
-      data gam cs(  6) / -.1893024529 7988804325 2394702388 6 d-3      /
-      data gam cs(  7) / +.3606925327 4412452565 7808221722 5 d-4      /
-      data gam cs(  8) / -.6056761904 4608642184 8554829036 5 d-5      /
-      data gam cs(  9) / +.1055829546 3022833447 3182350909 3 d-5      /
-      data gam cs( 10) / -.1811967365 5423840482 9185589116 6 d-6      /
-      data gam cs( 11) / +.3117724964 7153222777 9025459316 9 d-7      /
-      data gam cs( 12) / -.5354219639 0196871408 7408102434 7 d-8      /
-      data gam cs( 13) / +.9193275519 8595889468 8778682594 0 d-9      /
-      data gam cs( 14) / -.1577941280 2883397617 6742327395 3 d-9      /
-      data gam cs( 15) / +.2707980622 9349545432 6654043308 9 d-10     /
-      data gam cs( 16) / -.4646818653 8257301440 8166105893 3 d-11     /
-      data gam cs( 17) / +.7973350192 0074196564 6076717535 9 d-12     /
-      data gam cs( 18) / -.1368078209 8309160257 9949917230 9 d-12     /
-      data gam cs( 19) / +.2347319486 5638006572 3347177168 8 d-13     /
-      data gam cs( 20) / -.4027432614 9490669327 6657053469 9 d-14     /
-      data gam cs( 21) / +.6910051747 3721009121 3833697525 7 d-15     /
-      data gam cs( 22) / -.1185584500 2219929070 5238712619 2 d-15     /
-      data gam cs( 23) / +.2034148542 4963739552 0102605193 2 d-16     /
-      data gam cs( 24) / -.3490054341 7174058492 7401294910 8 d-17     /
-      data gam cs( 25) / +.5987993856 4853055671 3505106602 6 d-18     /
-      data gam cs( 26) / -.1027378057 8722280744 9006977843 1 d-18     /
-      data gam cs( 27) / +.1762702816 0605298249 4275966074 8 d-19     /
-      data gam cs( 28) / -.3024320653 7353062609 5877211204 2 d-20     /
-      data gam cs( 29) / +.5188914660 2183978397 1783355050 6 d-21     /
-      data gam cs( 30) / -.8902770842 4565766924 4925160106 6 d-22     /
-      data gam cs( 31) / +.1527474068 4933426022 7459689130 6 d-22     /
-      data gam cs( 32) / -.2620731256 1873629002 5732833279 9 d-23     /
-      data gam cs( 33) / +.4496464047 8305386703 3104657066 6 d-24     /
-      data gam cs( 34) / -.7714712731 3368779117 0390152533 3 d-25     /
-      data gam cs( 35) / +.1323635453 1260440364 8657271466 6 d-25     /
-      data gam cs( 36) / -.2270999412 9429288167 0231381333 3 d-26     /
-      data gam cs( 37) / +.3896418998 0039914493 2081663999 9 d-27     /
-      data gam cs( 38) / -.6685198115 1259533277 9212799999 9 d-28     /
-      data gam cs( 39) / +.1146998663 1400243843 4761386666 6 d-28     /
-      data gam cs( 40) / -.1967938586 3451346772 9510399999 9 d-29     /
-      data gam cs( 41) / +.3376448816 5853380903 3489066666 6 d-30     /
-      data gam cs( 42) / -.5793070335 7821357846 2549333333 3 d-31     /
+      data gamcs(  1) / +.8571195590 9893314219 2006239994 2 d-2      /
+      data gamcs(  2) / +.4415381324 8410067571 9131577165 2 d-2      /
+      data gamcs(  3) / +.5685043681 5993633786 3266458878 9 d-1      /
+      data gamcs(  4) / -.4219835396 4185605010 1250018662 4 d-2      /
+      data gamcs(  5) / +.1326808181 2124602205 8400679635 2 d-2      /
+      data gamcs(  6) / -.1893024529 7988804325 2394702388 6 d-3      /
+      data gamcs(  7) / +.3606925327 4412452565 7808221722 5 d-4      /
+      data gamcs(  8) / -.6056761904 4608642184 8554829036 5 d-5      /
+      data gamcs(  9) / +.1055829546 3022833447 3182350909 3 d-5      /
+      data gamcs( 10) / -.1811967365 5423840482 9185589116 6 d-6      /
+      data gamcs( 11) / +.3117724964 7153222777 9025459316 9 d-7      /
+      data gamcs( 12) / -.5354219639 0196871408 7408102434 7 d-8      /
+      data gamcs( 13) / +.9193275519 8595889468 8778682594 0 d-9      /
+      data gamcs( 14) / -.1577941280 2883397617 6742327395 3 d-9      /
+      data gamcs( 15) / +.2707980622 9349545432 6654043308 9 d-10     /
+      data gamcs( 16) / -.4646818653 8257301440 8166105893 3 d-11     /
+      data gamcs( 17) / +.7973350192 0074196564 6076717535 9 d-12     /
+      data gamcs( 18) / -.1368078209 8309160257 9949917230 9 d-12     /
+      data gamcs( 19) / +.2347319486 5638006572 3347177168 8 d-13     /
+      data gamcs( 20) / -.4027432614 9490669327 6657053469 9 d-14     /
+      data gamcs( 21) / +.6910051747 3721009121 3833697525 7 d-15     /
+      data gamcs( 22) / -.1185584500 2219929070 5238712619 2 d-15     /
+      data gamcs( 23) / +.2034148542 4963739552 0102605193 2 d-16     /
+      data gamcs( 24) / -.3490054341 7174058492 7401294910 8 d-17     /
+      data gamcs( 25) / +.5987993856 4853055671 3505106602 6 d-18     /
+      data gamcs( 26) / -.1027378057 8722280744 9006977843 1 d-18     /
+      data gamcs( 27) / +.1762702816 0605298249 4275966074 8 d-19     /
+      data gamcs( 28) / -.3024320653 7353062609 5877211204 2 d-20     /
+      data gamcs( 29) / +.5188914660 2183978397 1783355050 6 d-21     /
+      data gamcs( 30) / -.8902770842 4565766924 4925160106 6 d-22     /
+      data gamcs( 31) / +.1527474068 4933426022 7459689130 6 d-22     /
+      data gamcs( 32) / -.2620731256 1873629002 5732833279 9 d-23     /
+      data gamcs( 33) / +.4496464047 8305386703 3104657066 6 d-24     /
+      data gamcs( 34) / -.7714712731 3368779117 0390152533 3 d-25     /
+      data gamcs( 35) / +.1323635453 1260440364 8657271466 6 d-25     /
+      data gamcs( 36) / -.2270999412 9429288167 0231381333 3 d-26     /
+      data gamcs( 37) / +.3896418998 0039914493 2081663999 9 d-27     /
+      data gamcs( 38) / -.6685198115 1259533277 9212799999 9 d-28     /
+      data gamcs( 39) / +.1146998663 1400243843 4761386666 6 d-28     /
+      data gamcs( 40) / -.1967938586 3451346772 9510399999 9 d-29     /
+      data gamcs( 41) / +.3376448816 5853380903 3489066666 6 d-30     /
+      data gamcs( 42) / -.5793070335 7821357846 2549333333 3 d-31     /
 c
       data pi / 3.1415926535 8979323846 2643383279 50 d0 /
-c sq2pil is 0.5*alog(2*pi) = alog(sqrt(2*pi))
+c     sq2pil is 0.5*alog(2*pi) = alog(sqrt(2*pi))
       data sq2pil / 0.9189385332 0467274178 0329736405 62 d0 /
       data ngam, xmin, xmax, xsml, dxrel / 0, 4*0.d0 /
+      dgamma = -999d0
 c
-      if (ngam.ne.0) go to 10
-C     ngam = initds (gamcs, 42, 0.1*sngl(  d1mach) )
-      ngam = initds (gamcs, 42, 0.1*sngl(  EPSMIN ) )
+      if (ngam.eq.0) then
+C        ngam = initds (gamcs, 42, 0.1*sngl(  d1mach) )
+         ngam = initds (gamcs, 42, 0.1*sngl(  EPSMIN ) )
 c
-      call d9gaml (xmin, xmax)
-      if (IGAMMA .ne. 0) return
-C     xsml = dexp (dmax1 (dlog(d1mach(1)), -dlog(d1mach(2)))+0.01d0)
-      xsml =  exp ( max  ( log( FLTMIN  ), - log( FLTMAX  ))+0.01d0)
-C     dxrel = dsqrt (d1mach(4))
-      dxrel =  sqrt (  EPSMAX )
+         call d9gaml (xmin, xmax)
+         if (IGAMMA .ne. 0) return
+C        xsml = dexp (dmax1 (dlog(d1mach(1)), -dlog(d1mach(2)))+0.01d0)
+         xsml =  exp ( max  ( log( FLTMIN  ), - log( FLTMAX  ))+0.01d0)
+C        dxrel = dsqrt (d1mach(4))
+         dxrel =  sqrt (  EPSMAX )
 c
-C10   y = dabs(x)
- 10   y =  abs(x)
-      if (y.gt.10.d0) go to 50
+      endif
+C     y = dabs(x)
+      y =  abs(x)
+      if (y .gt. 10.d0) go to 50
 c
-c compute gamma(x) for -xbnd .le. x .le. xbnd.  reduce interval and find
-c gamma(1+y) for 0.0 .le. y .lt. 1.0 first of all.
+c     compute gamma(x) for -xbnd .le. x .le. xbnd.  reduce interval and find
+c     gamma(1+y) for 0.0 .le. y .lt. 1.0 first of all.
 c
       n = int(x)
       if (x.lt.0.d0) n = n - 1
       y = x - dble(float(n))
       n = n - 1
 C     dgamma = 0.9375d0 + dcsevl (2.d0*y-1.d0, gamcs, ngam)
-      temp = dcsevl (2.d0*y-1.d0, gamcs, ngam) 
+      temp = dcsevl (2.d0*y-1.d0, gamcs, ngam)
       if (IGAMMA .ne. 0) return
       dgamma = 0.9375d0 + temp
       if (n.eq.0) return
 c
       if (n.gt.0) go to 30
 c
-c compute gamma(x) for x .lt. 1.0
+c     compute gamma(x) for x .lt. 1.0
 c
       n = -n
 
 C     if (x.eq.0.d0) call seteru (14hdgamma  x is 0, 14, 4, 2)
-C     if (x.lt.0.0d0 .and. x+dble(float(n-2)).eq.0.d0) call seteru (
-C    1  31hdgamma  x is a negative integer, 31, 4, 2)
+C     if (x.lt.0d0 .and. x+dble(float(n-2)).eq.0.d0) call seteru (
+C     1  31hdgamma  x is a negative integer, 31, 4, 2)
 C     if (x.lt.(-0.5d0) .and. dabs((x-dint(x-0.5d0))/x).lt.dxrel) call
-C    1  seteru (68hdgamma  answer lt half precision because x too near n
-C    2egative integer, 68, 1, 1)
+C     1  seteru (68hdgamma  answer lt half precision because x too near n
+C     2egative integer, 68, 1, 1)
 C     if (y.lt.xsml) call seteru (
-C    1  54hdgamma  x is so close to 0.0 that the result overflows,
-C    2  54, 5, 2)
+C     1  54hdgamma  x is so close to 0.0 that the result overflows,
+C     2  54, 5, 2)
 
       if (x.eq.0.d0) then
-C       write(6,*) 'dgamma : x is 0'
-        IGAMMA = 11
-        return
+C     write(6,*) 'dgamma : x is 0'
+         IGAMMA = 11
+         return
       end if
 
-      if (x.lt.0.0d0 .and. x+dble(float(n-2)).eq.0.d0) then
-C       write( 6, *) 'dgamma : x is a negative integer'
-        IGAMMA = 12
-        return
+      if (x.lt.0d0 .and. x+dble(float(n-2)).eq.0.d0) then
+C     write( 6, *) 'dgamma : x is a negative integer'
+         IGAMMA = 12
+         return
       end if
 
       if (x.lt.(-0.5d0) .and. abs((x-dble(int(x-0.5d0)))/x).lt.dxrel)
-C    1  write(6,*) 'dgamma : answer lt half precision because
-C    2                       x too near a negative integer'
-     *  JGAMMA = 11
+C     1  write(6,*) 'dgamma : answer lt half precision because
+C     2                       x too near a negative integer'
+     *     JGAMMA = 11
 
       if (y.lt.xsml) then
-c       write(6,*)  'dgamma :,
-c    1               x is so close to 0.0 that the result overflows'
-        IGAMMA = 13
-        return
+c     write(6,*)  'dgamma :,
+c     1               x is so close to 0.0 that the result overflows'
+         IGAMMA = 13
+         return
       end if
 c
       do 20 i=1,n
-        dgamma = dgamma/(x+dble(float(i-1)) )
+         dgamma = dgamma/(x+dble(float(i-1)) )
  20   continue
       return
 c
-c gamma(x) for x .ge. 2.0 and x .le. 10.0
+c     gamma(x) for x .ge. 2.0 and x .le. 10.0
 c
  30   do 40 i=1,n
-        dgamma = (y+dble(float(i))) * dgamma
+         dgamma = (y+dble(float(i))) * dgamma
  40   continue
       return
 c
-c gamma(x) for dabs(x) .gt. 10.0.  recall y = dabs(x).
+c     gamma(x) for dabs(x) .gt. 10.0.  recall y = dabs(x).
 c
 C50   if (x.gt.xmax) call seteru (32hdgamma  x so big gamma overflows,
 C    1  32, 3, 2)
 
  50   if (x.gt.xmax) then
-c       write(6,*) 'dgamma : x so big gamma overflows'
-        IGAMMA = 14
-        return
+c     write(6,*) 'dgamma : x so big gamma overflows'
+         IGAMMA = 14
+         return
       end if
 c
       dgamma = 0.d0
 C     if (x.lt.xmin) call seteru (35hdgamma  x so small gamma underflows
-C    1  , 35, 2, 0)
+C     1  , 35, 2, 0)
 C     if (x.lt.xmin) return
 
       if (x.lt.xmin) then
-c       write(6,*) 'dgamma : x so small gamma underflows'
-        JGAMMA = 12
-        return
+c     write(6,*) 'dgamma : x so small gamma underflows'
+         JGAMMA = 12
+         return
       end if
 c
 C     dgamma = dexp ((y-0.5d0)*dlog(y) - y + sq2pil + d9lgmc(y) )
@@ -181,32 +188,33 @@ C     dgamma = dexp ((y-0.5d0)*dlog(y) - y + sq2pil + d9lgmc(y) )
       if (x.gt.0.d0) return
 c
 C     if (dabs((x-dint(x-0.5d0))/x).lt.dxrel) call seteru (
-C    1  61hdgamma  answer lt half precision, x too near negative integer
-C    2  , 61, 1, 1)
+C     1  61hdgamma  answer lt half precision, x too near negative integer
+C     2  , 61, 1, 1)
 
       if (abs((x-dble(int(x-0.5d0)))/x).lt.dxrel) JGAMMA = 11
 c
 C     sinpiy = dsin (pi*y)
       sinpiy =  sin (pi*y)
 C     if (sinpiy.eq.0.d0) call seteru (
-C    1  31hdgamma  x is a negative integer, 31, 4, 2)
- 
+C     1  31hdgamma  x is a negative integer, 31, 4, 2)
+
       if (sinpiy.eq.0.d0) then
-C       write(6,*) 'dgamma : x is a negative integer'
-        IGAMMA = 12
-        return
+C     write(6,*) 'dgamma : x is a negative integer'
+         IGAMMA = 12
+         return
       end if
 c
       dgamma = -pi/(y*sinpiy*dgamma)
 c
       return
       end
+
       double precision function dgamr (x)
 c july 1977 edition.  w. fullerton, c3, los alamos scientific lab.
 c this routine, not dgamma(x), should be the fundamental one.
 c
 C     double precision x, alngx, sgngx, dgamma, dint, dexp, d1mach
-      double precision x, alngx, sgngx, dgamma
+      double precision x, alngx, sgngx, temp,  dgamma
 
 C     external dexp, dgamma, dint, d1mach
       external dgamma
@@ -219,12 +227,12 @@ C     external dexp, dgamma, dint, d1mach
       common /GAMMFD/    IGAMMA, JGAMMA
       save   /GAMMFD/
 c
-      dgamr = 0.0d0
-C     if (x.le.0.0d0 .and. dint(x).eq.x) return
-      if (x.le.0.0d0 .and. dble(int(x)).eq.x) return
+      dgamr = 0d0
+C     if (x.le.0d0 .and. dint(x).eq.x) return
+      if (x.le.0d0 .and. dble(int(x)).eq.x) return
 c
 C     call entsrc (irold, 1)
-      if (dabs(x).gt.10.0d0) go to 10
+      if (dabs(x).gt.10d0) go to 10
 C     dgamr = 1.0d0/dgamma(x)
 C     call erroff
 C     call entsrc (ir, irold)
@@ -246,6 +254,7 @@ C     dgamr = sgngx * dexp(-alngx)
       return
 c
       end
+
       subroutine dlgams (x, dlgam, sgngam)
 c july 1977 edition.  w. fullerton, c3, los alamos scientific lab.
 c
@@ -254,6 +263,7 @@ c sgngam is either +1.0 or -1.0.
 c
 C     double precision x, dlgam, sgngam, dint, dlngam
       double precision x, dlgam, sgngam, dlngam
+      integer intx
 C     external dint, dlngam
       external dlngam
 
@@ -273,7 +283,8 @@ C     if (int.eq.0) sgngam = -1.0d0
 c
       return
       end
-      function initds (dos, nos, eta)
+
+      integer function initds (dos, nos, eta)
 c june 1977 edition.   w. fullerton, c3, los alamos scientific lab.
 c
 c initialize the double precision orthogonal series dos so that initds
@@ -285,7 +296,12 @@ c dos    dble prec array of nos coefficients in an orthogonal series.
 c nos    number of coefficients in dos.
 c eta    requested accuracy of series.
 c
+      integer nos
       double precision dos(nos)
+      real eta
+
+      integer ii, i
+      double precision err
 
       integer            IGAMMA, JGAMMA
       common /GAMMFD/    IGAMMA, JGAMMA
@@ -295,6 +311,7 @@ C     if (nos.lt.1) call seteru (
 C    1  35hinitds  number of coefficients lt 1, 35, 2, 2)
       if (nos.lt.1) JGAMMA = 31
 c
+      i = -1
       err = 0.
       do 10 ii=1,nos
         i = nos + 1 - ii
@@ -311,6 +328,7 @@ C     if (i.eq.nos) write(6,*) 'initds : eta may be too small'
 c
       return
       end
+
       subroutine d9gaml (xmin, xmax)
 c june 1977 edition.   w. fullerton, c3, los alamos scientific lab.
 c
@@ -326,7 +344,10 @@ c        value of x might cause overflow.
 c
 C     double precision xmin, xmax, alnbig, alnsml, xln, xold, d1mach,
 C    1  dlog
-      double precision xmin, xmax, alnbig, alnsml, xln, xold
+      double precision xmin, xmax
+
+      double precision alnbig, alnsml, xln, xold
+      integer i
 C     external d1mach, dlog
 
       double precision   FLTMIN, FLTMAX, EPSMIN, EPSMAX
@@ -379,6 +400,7 @@ c
 c
       return
       end
+
       double precision function d9lgmc (x)
 c august 1977 edition.  w. fullerton, c3, los alamos scientific lab.
 c
@@ -387,8 +409,13 @@ c dlog (dgamma(x)) = dlog(dsqrt(2*pi)) + (x-.5)*dlog(x) - x + d9lgmc(x)
 c
 C     double precision x, algmcs(15), xbig, xmax, dcsevl, d1mach,
 C    1  dexp, dlog, dsqrt
-      double precision x, algmcs(15), xbig, xmax, dcsevl
-      double precision temp
+      double precision x
+
+      double precision algmcs(15), xbig, xmax, temp
+      integer nalgm
+
+      double precision dcsevl
+      integer initds
 C     external d1mach, dcsevl, dexp, dlog, dsqrt, initds
       external dcsevl, initds
 
@@ -451,8 +478,8 @@ C    1  nalgm) / x
       if (x.lt.xbig) then
         temp   = dcsevl(2.0d0*(10.d0/x)**2-1.d0, algmcs, nalgm)
         if (IGAMMA .ne. 0) then
-C         d9gmlc = d1mach(2)
-          d9gmlc = FLTMAX
+C         d9lgmc = d1mach(2)
+          d9lgmc = FLTMAX
         else
           d9lgmc = temp / x
         end if
@@ -466,6 +493,7 @@ c     write(6,*) 'd9lgmc : x so big d9lgmc underflows'
       return
 c
       end
+
       double precision function dcsevl (x, a, n)
 c
 c evaluate the n-term chebyshev series a at x.  adapted from
@@ -477,9 +505,12 @@ c a      dble prec array of n terms of a chebyshev series.  in eval-
 c        uating a, only half the first coef is summed.
 c n      number of terms in array a.
 c
-      double precision a(n), x, twox, b0, b1, b2
+      integer n
+      double precision a(n), x
 C     double precision d1mach
 C     external         d1mach
+      double precision twox, b0, b1, b2
+      integer i, ni
 
       double precision   FLTMIN, FLTMAX, EPSMIN, EPSMAX
       common /MACHFD/    FLTMIN, FLTMAX, EPSMIN, EPSMAX
@@ -490,6 +521,7 @@ C     external         d1mach
       save   /GAMMFD/
 
 c
+      b2 = 0.
 C     if (n.lt.1) call seteru (28hdcsevl  number of terms le 0, 28, 2,2)
 C     if (n.gt.1000) call seteru (31hdcsevl  number of terms gt 1000,
 C    1  31, 3, 2)
@@ -534,12 +566,13 @@ c
 c
       return
       end
+
       double precision function dlngam (x)
-c august 1980 edition.   w. fullerton, c3, los alamos scientific lab.
+c     august 1980 edition.   w. fullerton, c3, los alamos scientific lab.
 C     double precision x, dxrel, pi, sinpiy, sqpi2l, sq2pil,
-C    1  y, xmax, dint, dgamma, d9lgmc, d1mach, dlog, dsin, dsqrt
+C     1  y, xmax, dint, dgamma, d9lgmc, d1mach, dlog, dsin, dsqrt
       double precision x, dxrel, pi, sinpiy, sqpi2l, sq2pil,
-     1  y, xmax, dgamma, d9lgmc
+     1     y, xmax, dgamma, d9lgmc
       double precision   temp
 C     external d1mach, d9lgmc, dgamma, dint, dlog, dsin, dsqrt
       external d9lgmc, dgamma
@@ -553,54 +586,55 @@ C     external d1mach, d9lgmc, dgamma, dint, dlog, dsin, dsqrt
       save   /GAMMFD/
 c
       data sq2pil / 0.9189385332 0467274178 0329736405 62 d0 /
-c sq2pil = alog (sqrt(2*pi)),  sqpi2l = alog(sqrt(pi/2))
-      data sqpi2l / +.2257913526 4472743236 3097614947 441 d+0    /
+c     sq2pil = alog (sqrt(2*pi)),  sqpi2l = alog(sqrt(pi/2))
+      data sqpi2l / +.2257913526 4472743236 3097614947 441 d0 /
       data pi / 3.1415926535 8979323846 2643383279 50 d0 /
 c
       data xmax, dxrel / 2*0.d0 /
 c
-      if (xmax.ne.0.d0) go to 10
-C     xmax = d1mach(2)/dlog(d1mach(2))
-      xmax =  FLTMAX  / log( FLTMAX  )
-C     dxrel = dsqrt (d1mach(4))
-      dxrel =  sqrt ( FLTMAX  )
-c
+      dlngam = 0d0
+      if (xmax .eq. 0) then
+C        xmax = d1mach(2)/dlog(d1mach(2))
+         xmax =  FLTMAX  / log( FLTMAX  )
+C        dxrel = dsqrt (d1mach(4))
+         dxrel =  sqrt ( FLTMAX  )
+       endif
 C10   y = dabs (x)
  10   y =  abs (x)
       if (y.gt.10.d0) go to 20
 c
-c dlog (dabs (dgamma(x)) ) for dabs(x) .le. 10.0
+c     dlog (dabs (dgamma(x)) ) for dabs(x) .le. 10.0
 c
 C     dlngam = dlog (dabs (dgamma(x)) )
       temp   = dgamma(x)
       if (IGAMMA .ne. 0) then
-C       dlngam = d1mach(2)
-        dlngam = FLTMAX
-        return
+C     dlngam = d1mach(2)
+         dlngam = FLTMAX
+         return
       end if
       dlngam = log (abs (temp) )
       return
 c
-c dlog ( dabs (dgamma(x)) ) for dabs(x) .gt. 10.0
+c     dlog ( dabs (dgamma(x)) ) for dabs(x) .gt. 10.0
 c
-C20   if (y.gt.xmax) call seteru (
-C    1  39hdlngam  dabs(x) so big dlngam overflows, 39, 2, 2)
- 
+C     20   if (y.gt.xmax) call seteru (
+C     1  39hdlngam  dabs(x) so big dlngam overflows, 39, 2, 2)
+
  20   if (y.gt.xmax) then
-c       write(6,*) 'dlngam : abs(x) so big dlngam overflows'
-        IGAMMA = 61
-C       dlngam = d1mach(2)
-        dlngam = FLTMAX
-        return
+c     write(6,*) 'dlngam : abs(x) so big dlngam overflows'
+         IGAMMA = 61
+C     dlngam = d1mach(2)
+         dlngam = FLTMAX
+         return
       end if
 c
 C     if (x.gt.0.d0) dlngam = sq2pil + (x-0.5d0)*dlog(x) - x + d9lgmc(y)
-       
+
       temp = d9lgmc(y)
       if (IGAMMA .ne. 0) then
-C       dlngam = d1mach(2)
-        dlngam = FLTMAX
-        return
+C     dlngam = d1mach(2)
+         dlngam = FLTMAX
+         return
       end if
 
       if (x.gt.0.d0) dlngam = sq2pil + (x-0.5d0)*log(x) - x + temp
@@ -609,30 +643,30 @@ c
 C     sinpiy = dabs (dsin(pi*y))
       sinpiy =  abs ( sin(pi*y))
 C     if (sinpiy.eq.0.d0) call seteru (
-C    1  31hdlngam  x is a negative integer, 31, 3, 2)
- 
+C     1  31hdlngam  x is a negative integer, 31, 3, 2)
+
       if (sinpiy.eq.0.d0) then
-c       write(6,*) 'dlngam : x is a negative integer'
-        IGAMMA = 62
-C       dlngam = d1mach(2)
-        dlngam = FLTMAX
-        return
+c     write(6,*) 'dlngam : x is a negative integer'
+         IGAMMA = 62
+C     dlngam = d1mach(2)
+         dlngam = FLTMAX
+         return
       end if
 c
 C     dlngam = sqpi2l + (x-0.5d0)*dlog(y) - x - dlog(sinpiy) - d9lgmc(y)
 
       temp = d9lgmc(y)
       if (IGAMMA .ne. 0) then
-C       dlngam = d1mach(2)
-        dlngam = FLTMAX
-        return
+C     dlngam = d1mach(2)
+         dlngam = FLTMAX
+         return
       end if
 
       dlngam = sqpi2l + (x-0.5d0)*log(y) - x - log(sinpiy) - temp
 c
 C     if (dabs((x-dint(x-0.5d0))*dlngam/x).lt.dxrel) call seteru (
-C    1  68hdlngam  answer lt half precision because x too near negative
-C    2integer, 68, 1, 1)
+C     1  68hdlngam  answer lt half precision because x too near negative
+C     2integer, 68, 1, 1)
       if ( abs((x-dble(int(x-0.5d0)))*dlngam/x).lt.dxrel) JGAMMA = 61
 
       return
